@@ -680,9 +680,8 @@ class SoundStreamTrainer(nn.Module):
                 self.log(**{f"discr_loss (scale {scale_factor})": loss})
 
         # log
-
+        wandb.log({"loss": logs['loss'], "step": steps})
         self.print(losses_str)
-        wandb.log({"loss": f"{logs['loss']:.3f}", "step": steps})
 
         # update exponential moving averaged generator
 
